Re-exports
pub use pgp;
Modules
- Public API for performing user actions, should be used for creating API implementations like the HTTP API or similar.
- Message storage and retreival for channels.
- Various objects for storing configuration.
- Errors
- GraphQL model definition.
- Definition of the HTTP API.
- Hubs, permission management, channel management and member management.
- Permissions are defined here.
- Server implementation.
- Definition of the WebSocket API.
Macros
- Checks that a hub member has a given permission and returns an error if it doesn’t.
Constants
- Maximum size of a description in bytes. Clients should be able to accept larger and smaller values.
- Maximum size of a username in bytes. Clients should be able to accept larger and smaller values.
- Maximum size of a user status in bytes. Clients should be able to accept larger and smaller values.
- Maximum size of a message in bytes. Clients should be able to accept larger and smaller values.
- How long to wait before commiting new messages to the tantivy search engine in milliseconds, this takes a lot of time, which is why it should be done only periodically.
Functions
- Wraps
is_valid_nameto return aResult<()>. - Checks if a name is valid (not too long and only allowed characters).
- Generates a new random ID.
- Starts WICRS Server in the current directory loading the configuration from
config.json.
Type Aliases
- Type used to represent IDs of non user objects throughout wicrs.